@@ -1,32 +1,24 @@
-use 5.16.0;
+use 5.20.0;
 use warnings;
-package Games::Nintendo::Mario;
-our $VERSION = 0.208; # <-- for PAUSE indexer
+package Games::Nintendo::Mario 0.209;
+# ABSTRACT: a class for jumping Italian plumbers
 
-=head1 NAME
-
-Games::Nintendo::Mario - a class for jumping Italian plumbers
-
-=head1 VERSION
-
-version 0.208
-
-=head1 SYNOPSIS
-
-  use Games::Nintendo::Mario;
-
-  my $hero = Games::Nintendo::Mario->new(name => 'Luigi');
-
-  $hero->damage; # cue the Mario Death Music
-
-=head1 DESCRIPTION
-
-This module provides a base class for representing the Mario Brothers from
-Nintendo's long-running Mario franchise of games.  Each Mario object keeps
-track of the plumber's current state and can be damaged or given powerups to
-change his state.
-
-=cut
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Games::Nintendo::Mario;
+#pod
+#pod   my $hero = Games::Nintendo::Mario->new(name => 'Luigi');
+#pod
+#pod   $hero->damage; # cue the Mario Death Music
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This module provides a base class for representing the Mario Brothers from
+#pod Nintendo's long-running Mario franchise of games.  Each Mario object keeps
+#pod track of the plumber's current state and can be damaged or given powerups to
+#pod change his state.
+#pod
+#pod =cut
 
 use Carp qw(cluck);
 
@@ -50,20 +42,18 @@ sub _goto {
   return $goto->{$item}{$state};
 }
 
-=head1 METHODS
-
-=head2 C<new>
-
-  my $hero = Games::Nintendo::Mario->new(name => 'Luigi');
-
-The constructor for Mario objects takes two named parameters, C<name> and
-C<state>.  C<name> must be either "Mario" or "Luigi" and C<state> must be
-"normal"
-
-If left undefined, C<name> and C<state> will default to "Mario" and "normal"
-respectively.
-
-=cut
+#pod =method new
+#pod
+#pod   my $hero = Games::Nintendo::Mario->new(name => 'Luigi');
+#pod
+#pod The constructor for Mario objects takes two named parameters, C<name> and
+#pod C<state>.  C<name> must be either "Mario" or "Luigi" and C<state> must be
+#pod "normal"
+#pod
+#pod If left undefined, C<name> and C<state> will default to "Mario" and "normal"
+#pod respectively.
+#pod
+#pod =cut
 
 sub new {
   my $class = shift;
@@ -87,15 +77,15 @@ sub new {
   bless $plumber => $class;
 }
 
-=head2 C<powerup>
-
-  $hero->powerup('hammer'); # this won't work
-
-As the base Games::Nintendo::Mario class represents Mario from the original
-Mario Bros., there is no valid way to call this method.  Subclasses
-representing Mario in other games may allow various powerup names to be passed.
-
-=cut
+#pod =method powerup
+#pod
+#pod   $hero->powerup('hammer'); # this won't work
+#pod
+#pod As the base Games::Nintendo::Mario class represents Mario from the original
+#pod Mario Bros., there is no valid way to call this method.  Subclasses
+#pod representing Mario in other games may allow various powerup names to be passed.
+#pod
+#pod =cut
 
 sub powerup {
   my $plumber = shift;
@@ -118,15 +108,15 @@ sub powerup {
   return $plumber;
 }
 
-=head2 C<damage>
-
-  $hero->damage;
-
-This method causes the object to react as if Mario has been attacked or
-damaged.  In the base Games::Nintendo::Mario class, this will always result in
-his death.
-
-=cut
+#pod =method damage
+#pod
+#pod   $hero->damage;
+#pod
+#pod This method causes the object to react as if Mario has been attacked or
+#pod damaged.  In the base Games::Nintendo::Mario class, this will always result in
+#pod his death.
+#pod
+#pod =cut
 
 sub damage {
   my $plumber = shift;
@@ -138,13 +128,13 @@ sub damage {
   return $plumber;
 }
 
-=head2 C<state>
-
-  print $hero->state;
-  
-This method accesses the name of Mario's current state.
-
-=cut
+#pod =method state
+#pod
+#pod   print $hero->state;
+#pod
+#pod This method accesses the name of Mario's current state.
+#pod
+#pod =cut
 
 sub state { ## no critic Homonym
   my $plumber = shift;
@@ -152,14 +142,14 @@ sub state { ## no critic Homonym
   return $plumber->{state};
 }
 
-=head2 C<name>
-
-  print $hero->name;
-
-This method returns the name of the plumber's current form.  (In the base
-class, this is always the same as the name passed to the constructor.)
-
-=cut
+#pod =method name
+#pod
+#pod   print $hero->name;
+#pod
+#pod This method returns the name of the plumber's current form.  (In the base
+#pod class, this is always the same as the name passed to the constructor.)
+#pod
+#pod =cut
 
 sub name {
   my $plumber = shift;
@@ -171,36 +161,130 @@ sub name {
   return $name;
 }
 
-=head2 C<games>
-
-  if (grep /World/, $hero->games) { ... }
-
-This returns a list of the games in which Mario behaved according to the model
-provided by this class.
-
-=cut
+#pod =method games
+#pod
+#pod   if (grep /World/, $hero->games) { ... }
+#pod
+#pod This returns a list of the games in which Mario behaved according to the model
+#pod provided by this class.
+#pod
+#pod =cut
 
 sub games {
   return ('Mario Bros.');
 }
 
+#pod =head1 TODO
+#pod
+#pod Wario, SMW.
+#pod
+#pod =cut
+
 "It's-a me!  Mario!";
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Games::Nintendo::Mario - a class for jumping Italian plumbers
+
+=head1 VERSION
+
+version 0.209
+
+=head1 SYNOPSIS
+
+  use Games::Nintendo::Mario;
+
+  my $hero = Games::Nintendo::Mario->new(name => 'Luigi');
+
+  $hero->damage; # cue the Mario Death Music
+
+=head1 DESCRIPTION
+
+This module provides a base class for representing the Mario Brothers from
+Nintendo's long-running Mario franchise of games.  Each Mario object keeps
+track of the plumber's current state and can be damaged or given powerups to
+change his state.
+
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
+=head1 METHODS
+
+=head2 new
+
+  my $hero = Games::Nintendo::Mario->new(name => 'Luigi');
+
+The constructor for Mario objects takes two named parameters, C<name> and
+C<state>.  C<name> must be either "Mario" or "Luigi" and C<state> must be
+"normal"
+
+If left undefined, C<name> and C<state> will default to "Mario" and "normal"
+respectively.
+
+=head2 powerup
+
+  $hero->powerup('hammer'); # this won't work
+
+As the base Games::Nintendo::Mario class represents Mario from the original
+Mario Bros., there is no valid way to call this method.  Subclasses
+representing Mario in other games may allow various powerup names to be passed.
+
+=head2 damage
+
+  $hero->damage;
+
+This method causes the object to react as if Mario has been attacked or
+damaged.  In the base Games::Nintendo::Mario class, this will always result in
+his death.
+
+=head2 state
+
+  print $hero->state;
+
+This method accesses the name of Mario's current state.
+
+=head2 name
+
+  print $hero->name;
+
+This method returns the name of the plumber's current form.  (In the base
+class, this is always the same as the name passed to the constructor.)
+
+=head2 games
+
+  if (grep /World/, $hero->games) { ... }
+
+This returns a list of the games in which Mario behaved according to the model
+provided by this class.
+
 =head1 TODO
 
 Wario, SMW.
 
 =head1 AUTHOR
 
-Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
+Ricardo SIGNES <cpan@semiotic.systems>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
+This software is copyright (c) 2003 by Ricardo SIGNES.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
